==> polyxmass-bin_0.8.7.orig.tar.gz: polyxmass-bin-0.8.7/src/polyxedit-ui-seqed-window-menu.h <==
/* GNU polyxmass - the massist's program.
   -------------------------------------- 
   Copyright (C) 2000,2001,2002,2003,2004 Filippo Rusconi

   http://www.polyxmass.org

   This file is part of the "GNU polyxmass" project.
   
   The "GNU polyxmass" project is an official GNU project package (see
   www.gnu.org) released ---in its entirety--- under the GNU General
   Public License and was started at the Centre National de la
   Recherche Scientifique (FRANCE), that granted me the formal
   authorization to publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
   
   You should have received a copy of the GNU  General Public
   License along with this software; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
#ifndef POLYXEDIT_UI_SEQED_WINDOW_MENU_H
#define POLYXEDIT_UI_SEQED_WINDOW_MENU_H

#include "polyxedit-globals.h"

#include "polyxedit-editctxt.h"



GtkWidget *
polyxedit_seqed_window_menubar_setup (GladeXML *xml, PxmEditCtxt *editctxt);



/* SAVE MENUITEM
 */
void
polyxedit_seqed_window_menu_file_save (GtkMenuItem *menuitem,
				       gpointer data);


/* SAVEAS MENUITEM
 */
void
polyxedit_seqed_window_menu_file_saveas (GtkMenuItem *menuitem,
					 gpointer data);


/* CLOSE MENUITEM
 */
void
polyxedit_seqed_window_menu_file_close (GtkMenuItem *menuitem,
					gpointer data);


/* EDIT MENUITEM
 */
void
polyxedit_seqed_window_menu_edit_copy (GtkMenuItem *menuitem,
				       gpointer data);

void
polyxedit_seqed_window_menu_edit_cut (GtkMenuItem *menuitem,
				      gpointer data);

void
polyxedit_seqed_window_menu_edit_paste (GtkMenuItem *menuitem,
					gpointer data);

void
polyxedit_seqed_window_menu_edit_export_sound_playlist (GtkMenuItem *menuitem,
						  gpointer data);

void
polyxedit_seqed_window_menu_edit_selectall (GtkMenuItem *menuitem,
					    gpointer data);

void
polyxedit_seqed_window_menu_edit_find (GtkMenuItem *menuitem,
				       gpointer data);

       

/* VIEW MENUITEM
 */
void
polyxedit_seqed_window_menu_view_calculationsoptions (GtkMenuItem *menuitem,
						      gpointer data);

void
polyxedit_seqed_window_menu_view_completionslist (GtkMenuItem *menuitem,
						  gpointer data);



/* CHEMISTRY MENUITEM
 */
void
polyxedit_seqed_window_menu_chemistry_modifs_monomer (GtkMenuItem *menuitem,
						      gpointer data);

void
polyxedit_seqed_window_menu_chemistry_modifs_polymer (GtkMenuItem *menuitem,
						      gpointer data);

void
polyxedit_seqed_window_menu_chemistry_cleave (GtkMenuItem *menuitem,
					      gpointer data);

void
polyxedit_seqed_window_menu_chemistry_fragment (GtkMenuItem *menuitem,
						gpointer data);

void
polyxedit_seqed_window_menu_chemistry_fragment (GtkMenuItem *menuitem,
						gpointer data);

void
polyxedit_seqed_window_menu_chemistry_compos_elem (GtkMenuItem *menuitem,
						   gpointer data);

void
polyxedit_seqed_window_menu_chemistry_compos_mnm (GtkMenuItem *menuitem,
						  gpointer data);

void
polyxedit_seqed_window_menu_chemistry_pka_ph_pi_reload_data (GtkMenuItem *
						      menuitem,  
						      gpointer data);

void
polyxedit_seqed_window_menu_chemistry_pka_ph_pi_computations (GtkMenuItem *
						       menuitem,  
						       gpointer data);

void
polyxedit_seqed_window_menu_chemistry_searchmass (GtkMenuItem *menuitem,
						  gpointer data);

void
polyxedit_seqed_window_menu_chemistry_mz_ratio_calc (GtkMenuItem *menuitem,
						     gpointer data);




#endif /* POLYXEDIT_UI_SEQED_WINDOW_MENU_H */

==> polyxmass-bin_0.8.9.orig.tar.gz: polyxmass-bin-0.8.9/src/polyxedit-ui-seqed-window-menu.h <==
/* GNU polyxmass - the massist's program.
   -------------------------------------- 
   Copyright (C) 2000,2001,2002,2003,2004 Filippo Rusconi

   http://www.polyxmass.org

   This file is part of the "GNU polyxmass" project.
   
   The "GNU polyxmass" project is an official GNU project package (see
   www.gnu.org) released ---in its entirety--- under the GNU General
   Public License and was started at the Centre National de la
   Recherche Scientifique (FRANCE), that granted me the formal
   authorization to publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
   
   You should have received a copy of the GNU  General Public
   License along with this software; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
#ifndef POLYXEDIT_UI_SEQED_WINDOW_MENU_H
#define POLYXEDIT_UI_SEQED_WINDOW_MENU_H

#include "polyxedit-globals.h"

#include "polyxedit-editctxt.h"



GtkWidget *
polyxedit_seqed_window_menubar_setup (GladeXML *xml, PxmEditCtxt *editctxt);



/* SAVE MENUITEM
 */
void
polyxedit_seqed_window_menu_file_save (GtkMenuItem *menuitem,
				       gpointer data);


/* SAVEAS MENUITEM
 */
void
polyxedit_seqed_window_menu_file_saveas (GtkMenuItem *menuitem,
					 gpointer data);


/* CLOSE MENUITEM
 */
void
polyxedit_seqed_window_menu_file_close (GtkMenuItem *menuitem,
					gpointer data);


/* EDIT MENUITEM
 */
void
polyxedit_seqed_window_menu_edit_copy (GtkMenuItem *menuitem,
				       gpointer data);

void
polyxedit_seqed_window_menu_edit_cut (GtkMenuItem *menuitem,
				      gpointer data);

void
polyxedit_seqed_window_menu_edit_paste (GtkMenuItem *menuitem,
					gpointer data);

void
polyxedit_seqed_window_menu_edit_self_read_configuration (GtkMenuItem *menuitem,
						  gpointer data);

void
polyxedit_seqed_window_menu_edit_selectall (GtkMenuItem *menuitem,
					    gpointer data);

void
polyxedit_seqed_window_menu_edit_find (GtkMenuItem *menuitem,
				       gpointer data);

       

/* VIEW MENUITEM
 */
void
polyxedit_seqed_window_menu_view_calculationsoptions (GtkMenuItem *menuitem,
						      gpointer data);

void
polyxedit_seqed_window_menu_view_completionslist (GtkMenuItem *menuitem,
						  gpointer data);



/* CHEMISTRY MENUITEM
 */
void
polyxedit_seqed_window_menu_chemistry_modifs_monomer (GtkMenuItem *menuitem,
						      gpointer data);

void
polyxedit_seqed_window_menu_chemistry_modifs_polymer (GtkMenuItem *menuitem,
						      gpointer data);

void
polyxedit_seqed_window_menu_chemistry_cleave (GtkMenuItem *menuitem,
					      gpointer data);

void
polyxedit_seqed_window_menu_chemistry_fragment (GtkMenuItem *menuitem,
						gpointer data);

void
polyxedit_seqed_window_menu_chemistry_fragment (GtkMenuItem *menuitem,
						gpointer data);

void
polyxedit_seqed_window_menu_chemistry_compos_elem (GtkMenuItem *menuitem,
						   gpointer data);

void
polyxedit_seqed_window_menu_chemistry_compos_mnm (GtkMenuItem *menuitem,
						  gpointer data);

void
polyxedit_seqed_window_menu_chemistry_pka_ph_pi_reload_data (GtkMenuItem *
						      menuitem,  
						      gpointer data);

void
polyxedit_seqed_window_menu_chemistry_pka_ph_pi_calculations (GtkMenuItem *
						       menuitem,  
						       gpointer data);

void
polyxedit_seqed_window_menu_chemistry_searchmass (GtkMenuItem *menuitem,
						  gpointer data);

void
polyxedit_seqed_window_menu_chemistry_mz_ratio_calc (GtkMenuItem *menuitem,
						     gpointer data);


/* REPORTING MENUITEM
 */
void
polyxedit_seqed_window_menu_reports_report_options (GtkMenuItem *menuitem,
					       gpointer data);

void
polyxedit_seqed_window_menu_reports_make_reports (GtkMenuItem *menuitem,
					  gpointer data);



#endif /* POLYXEDIT_UI_SEQED_WINDOW_MENU_H */
